@@ -4,6 +4,7 @@ from typing import Any, ContextManager, List, Optional
 
 import pytest
 from dirty_equals import IsStr
+from pydantic_core import PydanticUndefined
 
 from pydantic import (
     AliasChoices,
@@ -140,8 +141,8 @@ def test_alias_override_behavior():
         x: int = Field(alias='x1', gt=0)
 
     class Child(Parent):
-        x: int = Field(..., alias='x2')
-        y: int = Field(..., alias='y2')
+        x: int = Field(alias='x2')
+        y: int = Field(alias='y2')
 
     assert Parent.model_fields['x'].alias == 'x1'
     assert Child.model_fields['x'].alias == 'x2'
@@ -208,7 +209,7 @@ upper_alias_generator = [
 def test_alias_generator_on_parent(alias_generator):
     class Parent(BaseModel):
         model_config = ConfigDict(alias_generator=alias_generator)
-        x: bool = Field(..., alias='a_b_c')
+        x: bool = Field(alias='a_b_c')
         y: str
 
     class Child(Parent):
@@ -225,7 +226,7 @@ def test_alias_generator_on_parent(alias_generator):
 @pytest.mark.parametrize('alias_generator', upper_alias_generator)
 def test_alias_generator_on_child(alias_generator):
     class Parent(BaseModel):
-        x: bool = Field(..., alias='abc')
+        x: bool = Field(alias='abc')
         y: str
 
     class Child(Parent):
@@ -244,12 +245,12 @@ def test_alias_generator_used_by_default(alias_generator):
         model_config = ConfigDict(alias_generator=alias_generator)
 
         a: str
-        b: str = Field(..., alias='b_alias')
-        c: str = Field(..., validation_alias='c_val_alias')
-        d: str = Field(..., serialization_alias='d_ser_alias')
-        e: str = Field(..., alias='e_alias', validation_alias='e_val_alias')
-        f: str = Field(..., alias='f_alias', serialization_alias='f_ser_alias')
-        g: str = Field(..., alias='g_alias', validation_alias='g_val_alias', serialization_alias='g_ser_alias')
+        b: str = Field(alias='b_alias')
+        c: str = Field(validation_alias='c_val_alias')
+        d: str = Field(serialization_alias='d_ser_alias')
+        e: str = Field(alias='e_alias', validation_alias='e_val_alias')
+        f: str = Field(alias='f_alias', serialization_alias='f_ser_alias')
+        g: str = Field(alias='g_alias', validation_alias='g_val_alias', serialization_alias='g_ser_alias')
 
     assert {
         name: {k: getattr(f, k) for k in ('alias', 'validation_alias', 'serialization_alias')}
@@ -300,9 +301,9 @@ def test_alias_generator_used_by_default(alias_generator):
 @pytest.mark.parametrize('alias_generator', upper_alias_generator)
 def test_low_priority_alias(alias_generator):
     class Parent(BaseModel):
-        w: bool = Field(..., alias='w_', validation_alias='w_val_alias', serialization_alias='w_ser_alias')
+        w: bool = Field(alias='w_', validation_alias='w_val_alias', serialization_alias='w_ser_alias')
         x: bool = Field(
-            ..., alias='abc', alias_priority=1, validation_alias='x_val_alias', serialization_alias='x_ser_alias'
+            alias='abc', alias_priority=1, validation_alias='x_val_alias', serialization_alias='x_ser_alias'
         )
         y: str
 
@@ -402,7 +403,7 @@ def test_populate_by_name_config(
 
     class Foo(BaseModel):
         model_config = ConfigDict(populate_by_name=populate_by_name_config)
-        bar_: int = Field(..., alias='bar')
+        bar_: int = Field(alias='bar')
 
     with expectation:
         if use_construct:
@@ -585,6 +586,12 @@ def test_validation_alias_path(value):
     assert Model.model_fields['x'].validation_alias == value
 
 
+def test_search_dict_for_alias_path():
+    ap = AliasPath('a', 1)
+    assert ap.search_dict_for_path({'a': ['hello', 'world']}) == 'world'
+    assert ap.search_dict_for_path({'a': 'hello'}) is PydanticUndefined
+
+
 def test_validation_alias_invalid_value_type():
     m = 'Invalid `validation_alias` type. it should be `str`, `AliasChoices`, or `AliasPath`'
     with pytest.raises(TypeError, match=m):
@@ -613,7 +620,7 @@ def test_validation_alias_parse_data():
     ]
 
 
-def test_alias_generator() -> None:
+def test_alias_generator_class() -> None:
     class Model(BaseModel):
         a: str
 
@@ -702,3 +709,58 @@ def test_all_alias_kinds_specified() -> None:
     assert f.a == 'a'
     assert f.model_dump(by_alias=True) == {'a_ser_alias': 'a'}
     assert f.model_dump(by_alias=False) == {'a': 'a'}
+
+
+def test_alias_generator_with_computed_field_for_serialization() -> None:
+    """Tests that the alias generator is used for computed fields, with serialization_alias taking precedence over alias."""
+
+    class Rectangle(BaseModel):
+        model_config = ConfigDict(
+            alias_generator=AliasGenerator(
+                validation_alias=lambda field_name: f'{field_name}_val_alias',
+                alias=lambda field_name: f'{field_name}_alias',
+                serialization_alias=lambda field_name: f'{field_name}_ser_alias',
+            )
+        )
+
+        width: int
+        height: int
+
+        @computed_field
+        def area(self) -> int:
+            return self.width * self.height
+
+    r = Rectangle(width_val_alias=10, height_val_alias=20)
+    assert r.model_dump(by_alias=True) == {'width_ser_alias': 10, 'height_ser_alias': 20, 'area_ser_alias': 200}
+
+
+empty_str_alias_generator = AliasGenerator(
+    validation_alias=lambda x: '', alias=lambda x: f'{x}_alias', serialization_alias=lambda x: ''
+)
+
+
+def test_alias_gen_with_empty_string() -> None:
+    class Model(BaseModel):
+        a: str
+
+        model_config = ConfigDict(alias_generator=empty_str_alias_generator)
+
+    assert Model.model_fields['a'].validation_alias == ''
+    assert Model.model_fields['a'].serialization_alias == ''
+    assert Model.model_fields['a'].alias == 'a_alias'
+
+
+def test_alias_gen_with_empty_string_and_computed_field() -> None:
+    class Model(BaseModel):
+        model_config = ConfigDict(alias_generator=empty_str_alias_generator)
+
+        a: str
+
+        @computed_field
+        def b(self) -> str:
+            return self.a
+
+    assert Model.model_fields['a'].validation_alias == ''
+    assert Model.model_fields['a'].serialization_alias == ''
+    assert Model.model_fields['a'].alias == 'a_alias'
+    assert Model.model_computed_fields['b'].alias == ''
